schemetools.SchemeMoment
========================

.. abjad-lineage:: abjad.tools.schemetools.SchemeMoment.SchemeMoment

.. autoclass:: abjad.tools.schemetools.SchemeMoment.SchemeMoment

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.schemetools.SchemeMoment.SchemeMoment.duration
      ~abjad.tools.schemetools.SchemeMoment.SchemeMoment.force_quotes
      ~abjad.tools.schemetools.SchemeMoment.SchemeMoment.format_scheme_value
      ~abjad.tools.schemetools.SchemeMoment.SchemeMoment.__eq__
      ~abjad.tools.schemetools.SchemeMoment.SchemeMoment.__format__
      ~abjad.tools.schemetools.SchemeMoment.SchemeMoment.__ge__
      ~abjad.tools.schemetools.SchemeMoment.SchemeMoment.__gt__
      ~abjad.tools.schemetools.SchemeMoment.SchemeMoment.__le__
      ~abjad.tools.schemetools.SchemeMoment.SchemeMoment.__lt__
      ~abjad.tools.schemetools.SchemeMoment.SchemeMoment.__ne__
      ~abjad.tools.schemetools.SchemeMoment.SchemeMoment.__repr__
      ~abjad.tools.schemetools.SchemeMoment.SchemeMoment.__str__

Bases
-----

- :py:class:`schemetools.Scheme <abjad.tools.schemetools.Scheme.Scheme>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.duration
   :noindex:

.. autoattribute:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.force_quotes
   :noindex:

Class methods
-------------

.. automethod:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.format_scheme_value
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.__eq__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.__format__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.__ge__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.__gt__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.__le__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.__lt__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.__ne__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.__repr__
   :noindex:

.. automethod:: abjad.tools.schemetools.SchemeMoment.SchemeMoment.__str__
   :noindex:
